@@ -2,23 +2,24 @@ package controllers
 
 import (
 	"context"
-	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	apiconfigv1 "github.com/openshift/api/config/v1"
-	openshiftclientset "github.com/openshift/client-go/config/clientset/versioned"
 	stdlog "log"
 	"os"
 	"testing"
 	"time"
 
+	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
+	apiconfigv1 "github.com/openshift/api/config/v1"
+	openshiftclientset "github.com/openshift/client-go/config/clientset/versioned"
+
 	tlog "github.com/go-logr/logr/testing"
 	clusterfake "github.com/open-cluster-management/api/client/cluster/clientset/versioned/fake"
 	clusterinformers "github.com/open-cluster-management/api/client/cluster/informers/externalversions"
 	clusterv1alpha1 "github.com/open-cluster-management/api/cluster/v1alpha1"
-	clusterv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
-	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/agent"
-	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/clusterclaim"
 	configfake "github.com/openshift/client-go/config/clientset/versioned/fake"
 	routefake "github.com/openshift/client-go/route/clientset/versioned/fake"
+	clusterv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	"github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/agent"
+	"github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/clusterclaim"
 	"github.com/stretchr/testify/assert"
 	corev1 "k8s.io/api/core/v1"
 	extensionv1beta1 "k8s.io/api/extensions/v1beta1"
