@@ -5,10 +5,12 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/openshift/hive/apis/hive/v1/aws"
+
 	"github.com/onsi/ginkgo"
 	"github.com/onsi/gomega"
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
-	hiveinternalv1alpha1 "github.com/openshift/hive/pkg/apis/hiveinternal/v1alpha1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
+	hiveinternalv1alpha1 "github.com/openshift/hive/apis/hiveinternal/v1alpha1"
 	"github.com/stolostron/multicloud-operators-foundation/test/e2e/util"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -46,10 +48,21 @@ var _ = ginkgo.Describe("Testing BareMetalAsset", func() {
 				Namespace: testNamespace,
 			},
 			Spec: hivev1.ClusterDeploymentSpec{
-				BaseDomain:   "hive.example.com",
-				ClusterName:  testName,
-				Platform:     hivev1.Platform{},
-				Provisioning: &hivev1.Provisioning{},
+				BaseDomain:  "hive.example.com",
+				ClusterName: testName,
+				Platform: hivev1.Platform{
+					AWS: &aws.Platform{
+						CredentialsSecretRef: corev1.LocalObjectReference{
+							Name: "aws-clusterpool-aws-creds",
+						},
+						Region: "us-east",
+					},
+				},
+				Provisioning: &hivev1.Provisioning{
+					InstallConfigSecretRef: &corev1.LocalObjectReference{
+						Name: "secret-ref",
+					},
+				},
 				PullSecretRef: &corev1.LocalObjectReference{
 					Name: "pull-ref",
 				},
@@ -106,7 +119,7 @@ var _ = ginkgo.Describe("Testing BareMetalAsset", func() {
 				return true
 			}, eventuallyTimeout, eventuallyInterval).Should(gomega.BeTrue())
 
-			// manually update custersync status
+			// manually update clustersync status
 			clusterSync, err := hiveClient.HiveinternalV1alpha1().ClusterSyncs(testNamespace).Get(context.Background(), testName, metav1.GetOptions{})
 			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
 			clusterSync.Status.SyncSets = []hiveinternalv1alpha1.SyncStatus{
@@ -121,6 +134,26 @@ var _ = ginkgo.Describe("Testing BareMetalAsset", func() {
 			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
 			// ensure conditions of bma are correct
 			gomega.Eventually(func() error {
+				// sync status of syncSet in clusterSync
+				syncSet, err := hiveClient.HiveV1().SyncSets(testNamespace).Get(context.Background(), testName, metav1.GetOptions{})
+				if err != nil {
+					return nil
+				}
+
+				clusterSync, err := hiveClient.HiveinternalV1alpha1().ClusterSyncs(testNamespace).Get(context.Background(), testName, metav1.GetOptions{})
+				if err != nil {
+					return err
+				}
+				if len(clusterSync.Status.SyncSets) == 1 {
+					if clusterSync.Status.SyncSets[0].ObservedGeneration != syncSet.Generation {
+						clusterSync.Status.SyncSets[0].ObservedGeneration = syncSet.Generation
+						_, err := hiveClient.HiveinternalV1alpha1().ClusterSyncs(testNamespace).UpdateStatus(context.Background(), clusterSync, metav1.UpdateOptions{})
+						if err != nil {
+							return err
+						}
+					}
+				}
+
 				bma, err := dynamicClient.Resource(bmaGVR).Namespace(testNamespace).Get(context.Background(), testName, metav1.GetOptions{})
 				if err != nil {
 					return err
@@ -131,7 +164,10 @@ var _ = ginkgo.Describe("Testing BareMetalAsset", func() {
 				for _, condition := range conditions.([]interface{}) {
 					conditionStatus := condition.(map[string]interface{})["status"]
 					if conditionStatus.(string) != "True" {
-						return fmt.Errorf("contidion %v is not correct", condition.(map[string]interface{})["type"])
+						return fmt.Errorf("contidion %v is not correct, reason %v, message %v",
+							condition.(map[string]interface{})["type"],
+							condition.(map[string]interface{})["reason"],
+							condition.(map[string]interface{})["message"])
 					}
 				}
 				return nil
@@ -155,13 +191,18 @@ var _ = ginkgo.Describe("Testing BareMetalAsset", func() {
 		})
 
 		ginkgo.It("delete clusterdeployment should clean ref in bma", func() {
-			gomega.Eventually(func() (interface{}, error) {
+			gomega.Eventually(func() error {
 				cd, err := hiveClient.HiveV1().ClusterDeployments(testNamespace).Get(context.Background(), testName, metav1.GetOptions{})
 				if err != nil {
-					return []string{}, err
+					return err
 				}
-				return cd.Finalizers, nil
-			}, 60*time.Second, 1*time.Second).Should(gomega.Equal([]string{"baremetalasset.inventory.open-cluster-management.io"}))
+				for _, finalizer := range cd.Finalizers {
+					if finalizer == "baremetalasset.inventory.open-cluster-management.io" {
+						return nil
+					}
+				}
+				return fmt.Errorf("there is no finalizer baremetalasset.inventory.open-cluster-management.io")
+			}, 60*time.Second, 1*time.Second).ShouldNot(gomega.HaveOccurred())
 
 			gomega.Eventually(func() bool {
 				bma, err := util.GetResource(dynamicClient, bmaGVR, testNamespace, testName)
